Features — mosquittoChat 1.0.0 documentation

# Features

## Technical Specs

sockjs-client: | Advanced Websocket Javascript Client
Tornado: | Async Python Web Library + Web Server
sockjs-tornado: | SockJS websocket server implementation for Tornado
MQTT: | Machine-to-Machine (M2M)/”Internet of Things” connectivity protocol
paho-mqtt: | MQTT Python Client Library
Mosquitto: | A Message Broker implementing MQTT in C

## Feature Specs

- Public chat
- Shows who joined and who left
- Shows list of users online/offline
- Show last seen of offline features
- Shows who is typing and who is not - typing indicator
- Shows number of people online in public chat
- Join/Leave chat room features